#/bin/sh
#set -x
VER=1.3
REL=5
SDPTool_INSTALL_DIR="/usr/local/SDPTool"
SUPPORTED_OS="NO"
RH6_RELEASE=""
RH7_RELEASE=""
CENTOS6_RELEASE=""
CENTOS7_RELEASE=""
CHK_VER=""
CHK_REL=""
CWD=$( dirname "${BASH_SOURCE[0]}" )

print_success()
{
    echo -e "\e[32m==============================================="
    echo "Intel(R) SDPTool $VER-$REL installed successfully"
    echo -e "===============================================\e[0m"
}

print_installed()
{
    echo -e "\e[34m========================="
    echo "Package already installed"
    echo -e "=========================\e[0m"
}

print_update_old()
{
    echo -e "\e[34m============================================================="
    echo "Older version of the package ($CHK_VER-$CHK_REL) is installed"
    echo "Please use sdptool_update.sh to update the package to $VER-$REL"
    echo -e "=============================================================\e[0m"
}

print_newer()
{
    echo -e "\e[34m==============================================================="
    echo "Newer version of the package ($CHK_VER-$CHK_REL) is already installed"
    echo -e "===============================================================\e[0m"
}

print_current()
{
    echo -e "\e[34m========================================================"
    echo "Current version ($VER-$REL) of package is already installed"
    echo -e "========================================================\e[0m"
    
}

print_current_installed()
{
    echo -e "\e[34m================================"
    echo "Current Package $VER-$REL already installed"
    echo -e "================================\e[0m"
}

print_failure()
{
    echo -e "\e[31m==========================="
    echo "Package installation failed"
    echo -e "===========================\e[0m"
}

print_uninstall()
{
    echo "Please uninstall the package and then install"
}

print_refer()
{
    echo "Please refer to the User Guide in the following location :-"
    echo "/usr/share/doc/SDPTool/SDPTool_UserGuide_Rev_$VER.pdf"
    echo "--------------------------------------------------------------"
    echo "Please refer to the Release Notes in the following location :-"
    echo "/usr/share/doc/SDPTool/ReleaseNotes.txt"
    echo "--------------------------------------------------------------"
}

show_license()
{ 
    cat $CWD/Licenses/License.txt | more

    reply=
    while [[ $reply != "Y" && $reply != "y" && $reply != "N" && $reply != "n" ]]; do
	echo "Do you Accept? (Y/N)"
	read reply
    done

    if [[ $reply = "N" || $reply = "n" ]]; then
	exit
    fi
}

get_rpm_version()
{
    tmp_ver=`rpm -qi SDPTool | grep Version`
    CHK_VER=`awk '{split($0,c," "); print c[3]}' <<< $tmp_ver`
    tmp_rel=`rpm -qi SDPTool | grep Release`
    CHK_REL1=`awk '{split($0,c," "); print c[3]}' <<< $tmp_rel`
    CHK_REL=`awk '{split($0,c,"."); print c[1]}' <<< $CHK_REL1`
}

check_version()
{
    if [[ $CHK_VER > $VER ]] ; then
	print_newer
	exit 1
    elif [[ $CHK_VER < $VER ]] ; then
	print_update_old
	exit 1
    elif [[ $CHK_VER = $VER ]] ; then
	if [[ $CHK_REL = $REL ]] ; then
	    print_current
	    exit 1
	elif [[ $CHK_REL > $REL ]] ; then
	    print_newer
	    exit 1
	else
	    print_update_old
	    exit 1
	fi
    fi
}

check_installed()
{
    if rpm -q --quiet SDPTool ; then 
	get_rpm_version
	check_version
	return 1
    fi	
    if [ -d "/usr/local/SDPTool" ] ; then
	print_installed
	return 1
    fi
}

echo "Installing SDPTool Package ... "

check_installed
ret=$?
if [ "$ret" -eq 1 ] ; then
    exit 1
else
    show_license
    if [ -f "/etc/SuSE-release" ] ; then
	OSVer_11=$(grep "VERSION *= *11" /etc/SuSE-release)
	OSVer_12=$(grep "VERSION *= *12" /etc/SuSE-release)
	if [[ $OSVer_11 ]]; then
	    ARCH=`uname -m|grep x86_64 > /dev/null 2>&1`
	    if [ $? = 0 ] ; then
		rpm -ivh $CWD/RPMS/sles11_x/*.rpm 2>&1 | tee $CWD/install.log
	    fi
	elif [[ $OSVer_12 ]]; then
	    rpm -ivh $CWD/RPMS/sles12_x/*.rpm 2>&1 | tee $CWD/install.log
	fi
    elif [ -f /etc/redhat-release ] || [ -f /etc/centos-release ]; then
	if [ -f /etc/redhat-release ]; then
	    RH6_RELEASE=`grep -i "red hat .* release 6.*" /etc/redhat-release`
	    RH7_RELEASE=`grep -i "red hat .* release 7.*" /etc/redhat-release`
	fi
	if [ -f /etc/centos-release ]; then
	    CENTOS6_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-6.*"` 
	    CENTOS7_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-7.*"` 
	fi
	if [[ $RH7_RELEASE ]] ; then 
	    rpm -ivh $CWD/RPMS/rhel7_x/*.rpm 2>&1 | tee $CWD/install.log
	elif [[ $CENTOS7_RELEASE ]]; then
	    rpm -ivh $CWD/RPMS/centos7_x/*.rpm 2>&1 | tee $CWD/install.log
	elif [[ $RH6_RELEASE ]]; then
	    rpm -ivh $CWD/RPMS/rhel6_x/*.rpm 2>&1 | tee $CWD/install.log
	elif [[ $CENTOS6_RELEASE ]] ; then
	    rpm -ivh $CWD/RPMS/centos6_x/*.rpm 2>&1 | tee $CWD/install.log
	fi
	yum history new 2>&1 > /dev/null
    fi
fi

if [ -d "/usr/local/SDPTool" ] ; then
    print_success
    print_refer
else
    print_failure
    exit 1
fi
exit 0
