#!/bin/bash

VER=1.3
REL=5
CHK_VER=""
CHK_REL=""
CWD=$( dirname "${BASH_SOURCE[0]}" )

print_current()
{
    echo -e "\e[34m============================================"
    echo "Current version ($VER-$REL) is already installed"
    echo "Nothing to update .. exiting"
    echo -e "=============================================\e[0m"
}

print_newer()
{
    echo -e "\e[34m================================================"
    echo "Newer version ($CHK_VER-$CHK_REL) is already installed"
    echo "Nothing to update .. exiting"
    echo "================================================\e[0m"
}

print_uninstalled()
{
    echo -e "\e[34m============================="
    echo "SPDTool is not installed"
    echo "Nothing to update ..  exiting"
    echo -e "=============================\e[0m"
}

print_upgrade()
{
    echo -e "\e[34m======================================"
    echo "SPDTool was upgraded to version $VER-$REL"
    echo -e "======================================\e[0m"
}

print_dependency()
{
    echo -e "\e[31m======================================================================="
    echo "SPDTool has dependencies, please install them before installing SDPTool"
    echo -e "=======================================================================\e[0m"
}


check_installed()
{
    if rpm -q --quiet SDPTool ; then 
        return 1
    fi
    if [ -d "/usr/local/SDPTool" ] ; then
        return 2
    fi
}

get_rpm_version()
{
    tmp_ver=`rpm -qi SDPTool | grep Version`
    CHK_VER=`awk '{split($0,c," "); print c[3]}' <<< $tmp_ver`
    tmp_rel=`rpm -qi SDPTool | grep Release`
    CHK_REL1=`awk '{split($0,c," "); print c[3]}' <<< $tmp_rel`
    CHK_REL=`awk '{split($0,c,"."); print c[1]}' <<< $CHK_REL1`
}

uninstall()
{
    if [ -f "/etc/SuSE-release" ] ; then
        zypper remove -y SDPTool 2>&1 > $CWD/update.log
    elif [ -f "/etc/centos-release" ] ; then
        yum remove -y SDPTool 2>&1 > $CWD/update.log
    elif [ -f "/etc/redhat-release" ] ; then
        yum remove -y SDPTool 2>&1 > $CWD/update.log
    fi
    if [ -d /usr/local/SDPTool ] ; then
        rm -rf /usr/local/SDPTool 2>&1
    fi
    rm -rf /var/log/SDPTool 2>&1
}

show_license()
{ 
    cat $CWD/Licenses/License.txt | more

    reply=
    while [[ $reply != "Y" && $reply != "y" && $reply != "N" && $reply != "n" ]]; do
	echo "Do you Accept? (Y/N)"
	read reply
    done

    if [[ $reply = "N" || $reply = "n" ]]; then
	exit 1
    fi
}
 
install()
{
    show_license

    if [ -f "/etc/SuSE-release" ] ; then
	OSVer_11=$(grep "VERSION *= *11" /etc/SuSE-release)
	OSVer_12=$(grep "VERSION *= *12" /etc/SuSE-release)
	if [[ $OSVer_11 ]]; then
            ARCH=`uname -m|grep x86_64 > /dev/null 2>&1`
            if [ $? = 0 ] ; then
		rpm -ivh $CWD/RPMS/sles11_x/*.rpm 2>&1 | tee  $CWD/update.log
            fi
	elif [[ $OSVer_12 ]]; then
            rpm -ivh $CWD/RPMS/sles12_x/*.rpm 2>&1 | tee  $CWD/update.log
	fi
    elif [ -f /etc/redhat-release ] || [ -f /etc/centos-release ]; then
        if [ -f /etc/redhat-release ]; then
            RH6_RELEASE=`grep -i "red hat .* release 6.*" /etc/redhat-release`
            RH7_RELEASE=`grep -i "red hat .* release 7.*" /etc/redhat-release`
        fi
        if [ -f /etc/centos-release ]; then
            CENTOS6_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-6.*"` 
            CENTOS7_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-7.*"` 
        fi
        if [[ $RH7_RELEASE ]] ; then 
            rpm -ivh $CWD/RPMS/rhel7_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $CENTOS7_RELEASE ]]; then
            rpm -ivh $CWD/RPMS/centos7_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $RH6_RELEASE ]]; then
            rpm -ivh $CWD/RPMS/rhel6_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $CENTOS6_RELEASE ]] ; then
            rpm -ivh $CWD/RPMS/centos6_x/*.rpm 2>&1 | tee $CWD/update.log
        fi
	yum history new 2>&1 > /dev/null
    fi

    get_rpm_version

    if [[ $CHK_VER = $VER ]] ; then
	if [[ $CHK_REL = $REL ]] ; then
	    print_upgrade
	    exit 0
	fi
    fi
    print_dependency
    exit 1
}

upgrade()
{
    get_rpm_version

    if [[ $CHK_VER = $VER ]] ; then
	if [[ $CHK_REL = $REL ]] ; then
	    print_current
	    exit 1
	elif [[ $CHK_REL > $REL ]] ; then
	    print_newer
	    exit 1
	fi
    elif [[ $CHK_VER > $VER ]] ; then
	print_newer
	exit 1
    fi

    show_license

    if [ -f "/etc/SuSE-release" ] ; then
	OSVer_11=$(grep "VERSION *= *11" /etc/SuSE-release)
	OSVer_12=$(grep "VERSION *= *12" /etc/SuSE-release)
	if [[ $OSVer_11 ]]; then
            ARCH=`uname -m|grep x86_64 > /dev/null 2>&1`
            if [ $? = 0 ] ; then
		rpm -Uvh $CWD/RPMS/sles11_x/*.rpm 2>&1 | tee  $CWD/update.log
            fi
	elif [[ $OSVer_12 ]]; then
            rpm -Uvh $CWD/RPMS/sles12_x/*.rpm 2>&1 | tee  $CWD/update.log
	fi
    elif [ -f /etc/redhat-release ] || [ -f /etc/centos-release ]; then
        if [ -f /etc/redhat-release ]; then
            RH6_RELEASE=`grep -i "red hat .* release 6.*" /etc/redhat-release`
            RH7_RELEASE=`grep -i "red hat .* release 7.*" /etc/redhat-release`
        fi
        if [ -f /etc/centos-release ]; then
            CENTOS6_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-6.*"` 
            CENTOS7_RELEASE=`rpm -qf /etc/centos-release | grep -i "centos-release-7.*"` 
        fi
        if [[ $RH7_RELEASE ]] ; then 
            rpm -Uvh $CWD/RPMS/rhel7_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $CENTOS7_RELEASE ]]; then
            rpm -Uvh $CWD/RPMS/centos7_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $RH6_RELEASE ]]; then
            rpm -Uvh $CWD/RPMS/rhel6_x/*.rpm 2>&1 | tee $CWD/update.log
        elif [[ $CENTOS6_RELEASE ]] ; then
            rpm -Uvh $CWD/RPMS/centos6_x/*.rpm 2>&1 | tee $CWD/update.log
        fi
	yum history new 2>&1 > /dev/null
    fi

    get_rpm_version

    if [[ $CHK_VER = $VER ]] ; then
	if [[ $CHK_REL = $REL ]] ; then
	    print_upgrade
	    exit 0
	fi
    fi
    print_dependency
    exit 1
}

echo "Updating SDPTool ... "

check_installed
ret=$?
if [ "$ret" -eq 2 ] ; then
    uninstall
    install
elif [ "$ret" -eq 1 ] ; then
    upgrade
else
    print_uninstalled
    exit 1
fi
